@@ -3,7 +3,7 @@
 # :Author:    John Anderson <sontek@gmail.com>
 # :License:   MIT License
 # :Copyright: © 2015 John Anderson
-# :Copyright: © 2016, 2017 Lele Gaifax
+# :Copyright: © 2016, 2017, 2018 Lele Gaifax
 #
 
 import random
@@ -17,7 +17,9 @@ import rapidjson as rj
 @pytest.mark.unit
 @pytest.mark.parametrize(
     'value', (
-        'A', 'cruel\x00world', 1, -1, 2.3,
+        'A', 'cruel\x00world',
+        1, -1,
+        2.3, -36.973846435546875, 1514893636.276703,
         {'foo': 'bar', '\x00': 'issue57', 'issue57': '\x00'},
         [1, 2, 'a', 1.2, {'foo': 'bar'},],
         sys.maxsize, sys.maxsize**2,
